@@ -206,7 +206,7 @@ def create_changelog(repo=None,
         if batch == 'milestones':
             milestones = [i.get('title') for i in gh.milestones()]
             empty_items = [None] * len(milestones)
-            items = zip(*(milestones, empty_items, empty_items))
+            items = list(zip(milestones, empty_items, empty_items))
         elif batch == 'tags':
             tags = [
                 i.get('ref', '').replace('refs/tags/', '') for i in gh.tags()
@@ -214,7 +214,7 @@ def create_changelog(repo=None,
             since_tags = [None] + tags
             until_tags = tags + [None]
             empty_items = [None] * len(since_tags)
-            items = zip(*(empty_items, since_tags, until_tags))
+            items = list(zip(empty_items, since_tags, until_tags))
     else:
         base_issues = None
         if milestone:
